@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Header: /Users/claude/fuzz/lib/Genezzo/Row/RCS/RSTab.pm,v 6.7 2004/09/27 08:50:15 claude Exp $
+# $Header: /Users/claude/fuzz/lib/Genezzo/Row/RCS/RSTab.pm,v 6.8 2004/12/14 07:53:32 claude Exp claude $
 #
 # copyright (c) 2003, 2004 Jeffrey I Cohen, all rights reserved, worldwide
 #
@@ -1585,4 +1585,7 @@ Copyright (c) 2003, 2004 Jeffrey I Cohen.  All rights reserved.
 
 Address bug reports and comments to: jcohen@genezzo.com
 
+For more information, please visit the Genezzo homepage 
+at http://www.genezzo.com
+
 =cut
